@@ -2,12 +2,14 @@
 Template tag tests.
 """
 
+from django.conf import settings
+from django.contrib.auth.models import User, AnonymousUser
+from django.http import HttpRequest
 from django import template
 from django.test import TestCase
 
 from django_clicky.templatetags.clicky import ClickyException
 from django_clicky.tests.utils import TestSettingsManager
-from django.http import HttpRequest
 
 
 class TrackClickyTagTestCase(TestCase):
@@ -60,7 +62,7 @@ class TrackClickyTagTestCase(TestCase):
         req = HttpRequest()
         req.META['REMOTE_ADDR'] = '1.1.1.1'
         r = self.render_tag({'request': req})
-        self.assertFalse('var clicky_site_id = 12345678;' in r, r)
+        self.assertEqual(r, "")
 
     def test_render_internal_ip_forwarded(self):
         self.settings_manager.set(CLICKY_SITE_ID='12345678',
@@ -68,7 +70,7 @@ class TrackClickyTagTestCase(TestCase):
         req = HttpRequest()
         req.META['HTTP_X_FORWARDED_FOR'] = '1.1.1.1'
         r = self.render_tag({'request': req})
-        self.assertFalse('var clicky_site_id = 12345678;' in r, r)
+        self.assertEqual(r, "")
 
     def test_render_not_internal_ip(self):
         self.settings_manager.set(CLICKY_SITE_ID='12345678',
@@ -77,3 +79,33 @@ class TrackClickyTagTestCase(TestCase):
         req.META['REMOTE_ADDR'] = '2.2.2.2'
         r = self.render_tag({'request': req})
         self.assertTrue('var clicky_site_id = 12345678;' in r, r)
+
+    def test_render_session_user(self):
+        installed_apps = set(settings.INSTALLED_APPS)
+        installed_apps.add('django.contrib.auth')
+        installed_apps.add('django.contrib.contenttypes')
+        self.settings_manager.set(
+            INSTALLED_APPS=list(installed_apps),
+            TEMPLATE_CONTEXT_PROCESSORS=[
+                    'django.contrib.auth.context_processors.auth'],
+            CLICKY_SITE_ID='12345678',
+            CLICKY_INTERNAL_IPS=['1.1.1.1'],
+        )
+        user = User(username='test')
+        r = self.render_tag({'user': user})
+        self.assertTrue("clicky_custom.session = {username: 'test'};" in r, r)
+
+    def test_render_session_anon_user(self):
+        installed_apps = set(settings.INSTALLED_APPS)
+        installed_apps.add('django.contrib.auth')
+        installed_apps.add('django.contrib.contenttypes')
+        self.settings_manager.set(
+            INSTALLED_APPS=list(installed_apps),
+            TEMPLATE_CONTEXT_PROCESSORS=[
+                    'django.contrib.auth.context_processors.auth'],
+            CLICKY_SITE_ID='12345678',
+            CLICKY_INTERNAL_IPS=['1.1.1.1'],
+        )
+        user = AnonymousUser()
+        r = self.render_tag({'user': user})
+        self.assertFalse("clicky_custom.session = {username:" in r, r)
